@@ -8,12 +8,9 @@
 /**
  * Module dependencies.
  */
-
-const {nanoid} = require('nanoid/non-secure');
 var path = require('path');
 var util = require('util');
 var he = require('he');
-const errors = require('./errors');
 
 const MOCHA_ID_PROP_NAME = '__mocha_id__';
 
@@ -35,7 +32,7 @@ exports.inherits = util.inherits;
  * @param  {string} html
  * @return {string}
  */
-exports.escape = function(html) {
+exports.escape = function (html) {
   return he.encode(String(html), {useNamedReferences: false});
 };
 
@@ -46,7 +43,7 @@ exports.escape = function(html) {
  * @param {Object} obj
  * @return {boolean}
  */
-exports.isString = function(obj) {
+exports.isString = function (obj) {
   return typeof obj === 'string';
 };
 
@@ -57,7 +54,7 @@ exports.isString = function(obj) {
  * @param {string} str
  * @return {string}
  */
-exports.slug = function(str) {
+exports.slug = function (str) {
   return str
     .toLowerCase()
     .replace(/\s+/g, '-')
@@ -71,13 +68,13 @@ exports.slug = function(str) {
  * @param {string} str
  * @return {string}
  */
-exports.clean = function(str) {
+exports.clean = function (str) {
   str = str
     .replace(/\r\n?|[\n\u2028\u2029]/g, '\n')
     .replace(/^\uFEFF/, '')
     // (traditional)->  space/name     parameters    body     (lambda)-> parameters       body   multi-statement/single          keep body content
     .replace(
-      /^function(?:\s*|\s+[^(]*)\([^)]*\)\s*\{((?:.|\n)*?)\s*\}$|^\([^)]*\)\s*=>\s*(?:\{((?:.|\n)*?)\s*\}|((?:.|\n)*))$/,
+      /^function(?:\s*|\s[^(]*)\([^)]*\)\s*\{((?:.|\n)*?)\}$|^\([^)]*\)\s*=>\s*(?:\{((?:.|\n)*?)\}|((?:.|\n)*))$/,
       '$1$2$3'
     );
 
@@ -213,7 +210,7 @@ exports.type = function type(value) {
  * @param {*} value
  * @return {string}
  */
-exports.stringify = function(value) {
+exports.stringify = function (value) {
   var typeHint = canonicalType(value);
 
   if (!~['object', 'array', 'function'].indexOf(typeHint)) {
@@ -229,7 +226,7 @@ exports.stringify = function(value) {
     // IE7/IE8 has a bizarre String constructor; needs to be coerced
     // into an array and back to obj.
     if (typeHint === 'string' && typeof value === 'object') {
-      value = value.split('').reduce(function(acc, char, idx) {
+      value = value.split('').reduce(function (acc, char, idx) {
         acc[idx] = char;
         return acc;
       }, {});
@@ -298,6 +295,9 @@ function jsonStringify(object, spaces, depth) {
             ? '-0'
             : val.toString();
         break;
+      case 'bigint':
+        val = val.toString() + 'n';
+        break;
       case 'date':
         var sDate = isNaN(val.getTime()) ? val.toString() : val.toISOString();
         val = '[Date: ' + sDate + ']';
@@ -381,14 +381,14 @@ exports.canonicalize = function canonicalize(value, stack, typeHint) {
       canonicalizedObj = value;
       break;
     case 'array':
-      withStack(value, function() {
-        canonicalizedObj = value.map(function(item) {
+      withStack(value, function () {
+        canonicalizedObj = value.map(function (item) {
           return exports.canonicalize(item, stack);
         });
       });
       break;
     case 'function':
-      /* eslint-disable-next-line no-unused-vars */
+      /* eslint-disable-next-line no-unused-vars, no-unreachable-loop */
       for (prop in value) {
         canonicalizedObj = {};
         break;
@@ -401,10 +401,10 @@ exports.canonicalize = function canonicalize(value, stack, typeHint) {
     /* falls through */
     case 'object':
       canonicalizedObj = canonicalizedObj || {};
-      withStack(value, function() {
+      withStack(value, function () {
         Object.keys(value)
           .sort()
-          .forEach(function(key) {
+          .forEach(function (key) {
             canonicalizedObj[key] = exports.canonicalize(value[key], stack);
           });
       });
@@ -432,7 +432,7 @@ exports.canonicalize = function canonicalize(value, stack, typeHint) {
  * (i.e: strip Mocha and internal node functions from stack trace).
  * @returns {Function}
  */
-exports.stackTraceFilter = function() {
+exports.stackTraceFilter = function () {
   // TODO: Replace with `process.browser`
   var is = typeof document === 'undefined' ? {node: true} : {browser: true};
   var slash = path.sep;
@@ -440,9 +440,8 @@ exports.stackTraceFilter = function() {
   if (is.node) {
     cwd = exports.cwd() + slash;
   } else {
-    cwd = (typeof location === 'undefined'
-      ? window.location
-      : location
+    cwd = (
+      typeof location === 'undefined' ? window.location : location
     ).href.replace(/\/[^/]*$/, '/');
     slash = '/';
   }
@@ -466,10 +465,10 @@ exports.stackTraceFilter = function() {
     );
   }
 
-  return function(stack) {
+  return function (stack) {
     stack = stack.split('\n');
 
-    stack = stack.reduce(function(list, line) {
+    stack = stack.reduce(function (list, line) {
       if (isMochaInternal(line)) {
         return list;
       }
@@ -516,49 +515,11 @@ exports.clamp = function clamp(value, range) {
   return Math.min(Math.max(value, range[0]), range[1]);
 };
 
-/**
- * Single quote text by combining with undirectional ASCII quotation marks.
- *
- * @description
- * Provides a simple means of markup for quoting text to be used in output.
- * Use this to quote names of variables, methods, and packages.
- *
- * <samp>package 'foo' cannot be found</samp>
- *
- * @private
- * @param {string} str - Value to be quoted.
- * @returns {string} quoted value
- * @example
- * sQuote('n') // => 'n'
- */
-exports.sQuote = function(str) {
-  return "'" + str + "'";
-};
-
-/**
- * Double quote text by combining with undirectional ASCII quotation marks.
- *
- * @description
- * Provides a simple means of markup for quoting text to be used in output.
- * Use this to quote names of datatypes, classes, pathnames, and strings.
- *
- * <samp>argument 'value' must be "string" or "number"</samp>
- *
- * @private
- * @param {string} str - Value to be quoted.
- * @returns {string} quoted value
- * @example
- * dQuote('number') // => "number"
- */
-exports.dQuote = function(str) {
-  return '"' + str + '"';
-};
-
 /**
  * It's a noop.
  * @public
  */
-exports.noop = function() {};
+exports.noop = function () {};
 
 /**
  * Creates a map-like object.
@@ -575,7 +536,7 @@ exports.noop = function() {};
  * @param {...*} [obj] - Arguments to `Object.assign()`.
  * @returns {Object} An object with no prototype, having `...obj` properties
  */
-exports.createMap = function(obj) {
+exports.createMap = function (obj) {
   return Object.assign.apply(
     null,
     [Object.create(null)].concat(Array.prototype.slice.call(arguments))
@@ -594,39 +555,13 @@ exports.createMap = function(obj) {
  * @returns {Object} A frozen object with no prototype, having `...obj` properties
  * @throws {TypeError} if argument is not a non-empty object.
  */
-exports.defineConstants = function(obj) {
+exports.defineConstants = function (obj) {
   if (canonicalType(obj) !== 'object' || !Object.keys(obj).length) {
     throw new TypeError('Invalid argument; expected a non-empty object');
   }
   return Object.freeze(exports.createMap(obj));
 };
 
-/**
- * Whether current version of Node support ES modules
- *
- * @description
- * Versions prior to 10 did not support ES Modules, and version 10 has an old incompatible version of ESM.
- * This function returns whether Node.JS has ES Module supports that is compatible with Mocha's needs,
- * which is version >=12.11.
- *
- * @param {partialSupport} whether the full Node.js ESM support is available (>= 12) or just something that supports the runtime (>= 10)
- *
- * @returns {Boolean} whether the current version of Node.JS supports ES Modules in a way that is compatible with Mocha
- */
-exports.supportsEsModules = function(partialSupport) {
-  if (!exports.isBrowser() && process.versions && process.versions.node) {
-    var versionFields = process.versions.node.split('.');
-    var major = +versionFields[0];
-    var minor = +versionFields[1];
-
-    if (!partialSupport) {
-      return major >= 13 || (major === 12 && minor >= 11);
-    } else {
-      return major >= 10;
-    }
-  }
-};
-
 /**
  * Returns current working directory
  *
@@ -647,35 +582,6 @@ exports.isBrowser = function isBrowser() {
   return Boolean(process.browser);
 };
 
-/**
- * Lookup file names at the given `path`.
- *
- * @description
- * Filenames are returned in _traversal_ order by the OS/filesystem.
- * **Make no assumption that the names will be sorted in any fashion.**
- *
- * @public
- * @alias module:lib/cli.lookupFiles
- * @param {string} filepath - Base path to start searching from.
- * @param {string[]} [extensions=[]] - File extensions to look for.
- * @param {boolean} [recursive=false] - Whether to recurse into subdirectories.
- * @return {string[]} An array of paths.
- * @throws {Error} if no files match pattern.
- * @throws {TypeError} if `filepath` is directory and `extensions` not provided.
- * @deprecated Moved to {@link module:lib/cli.lookupFiles}
- */
-exports.lookupFiles = (...args) => {
-  if (exports.isBrowser()) {
-    throw errors.createUnsupportedError(
-      'lookupFiles() is only supported in Node.js!'
-    );
-  }
-  errors.deprecate(
-    '`lookupFiles()` in module `mocha/lib/utils` has moved to module `mocha/lib/cli` and will be removed in the next major revision of Mocha'
-  );
-  return require('./cli').lookupFiles(...args);
-};
-
 /*
  * Casts `value` to an array; useful for optionally accepting array parameters
  *
@@ -707,11 +613,22 @@ exports.constants = exports.defineConstants({
   MOCHA_ID_PROP_NAME
 });
 
+const uniqueIDBase =
+  'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_';
+
 /**
  * Creates a new unique identifier
+ * Does not create cryptographically safe ids.
+ * Trivial copy of nanoid/non-secure
  * @returns {string} Unique identifier
  */
-exports.uniqueID = () => nanoid();
+exports.uniqueID = () => {
+  let id = '';
+  for (let i = 0; i < 21; i++) {
+    id += uniqueIDBase[(Math.random() * 64) | 0];
+  }
+  return id;
+};
 
 exports.assignNewMochaID = obj => {
   const id = exports.uniqueID();
